CompletableFutureUseCase<Params> class abstract

A streamlined UseCase that performs a task without returning a value.

Inheritance

Constructors

CompletableFutureUseCase()

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildUseCaseFuture(Params? params) Future<void>
Builds the Future to be awaited. Params is required by the UseCase to retrieve the appropriate data from the repository.
override
execute(Observer<void> observer, [Params? params]) Future<void>
Executes a single-shot use case and triggers Observer callbacks.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited