desktopView property
Widget
get
desktopView
To be implemented by the developer which will build on Desktop ViewPort.
The default breakpoint value is 950
Implementation
Widget get desktopView;
To be implemented by the developer which will build on Desktop ViewPort.
The default breakpoint value is 950
Widget get desktopView;