mobileView property
Widget
get
mobileView
To be implemented by the developer which will build on Mobile ViewPort.
The default breakpoint value is more than 375
Implementation
Widget get mobileView;
To be implemented by the developer which will build on Mobile ViewPort.
The default breakpoint value is more than 375
Widget get mobileView;