watchView property
Widget
get
watchView
To be implemented by the developer which will build on Watch ViewPort.
The default breakpoint value is less than 300
Implementation
Widget get watchView;
To be implemented by the developer which will build on Watch ViewPort.
The default breakpoint value is less than 300
Widget get watchView;