FutureUseCase<T, Params> class
abstract
A streamlined UseCase for single-shot requests that don't need streams. It executes a single Future and maps the result to Observer callbacks.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildUseCaseFuture(
Params? params) → Future< T?> -
Builds the Future to be awaited.
Paramsis required by the UseCase to retrieve the appropriate data from the repository. -
execute(
Observer< T> observer, [Params? params]) → Future<void> - Executes a single-shot use case and triggers Observer callbacks.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited